pub enum CacheMode {
UseCache,
RebuildCache,
}Expand description
Track cover art caching mode used when indexing the music library.
Variants
UseCache
Use cached cover art images when possible.
RebuildCache
Discard cached cover art images and extract them when indexing.