pub enum IndexingIntensity {
Fast,
Balanced,
Lightweight,
}Expand description
Defines the intensity level for resource allocation during indexing.
The indexer will always allocate at least one CPU core.
Variants
Fast
Use all available CPU cores.
Balanced
Use half the available CPU cores.
Lightweight
Use a quarter of the available CPU cores.